#
# spec file for package tilix
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gtkd_version 3.7.5
Name:           tilix
Version:        1.7.7
Release:        lp150.2.2
Summary:        A tiling terminal emulator based on GTK+ 3
License:        MPL-2.0
Group:          System/X11/Terminals
URL:            https://github.com/gnunn1/tilix
Source0:        https://github.com/gnunn1/tilix/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# See https://github.com/dlang/dub/issues/838 on why we need to have the full source code as dependency
Source1:        https://github.com/gtkd-developers/GtkD/archive/v%{gtkd_version}.tar.gz#/GtkD-%{gtkd_version}.tar.gz
Patch0:         gnome-ssh-agent.patch
Patch1:         dynamic-link.patch
BuildRequires:  dmd
BuildRequires:  dub
BuildRequires:  hicolor-icon-theme
BuildRequires:  phobos-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(vte-2.91)
Requires:       dconf
Requires:       gtk3
Requires:       vte
Conflicts:      nautilus-extension-terminix
Conflicts:      terminix

%description
A tiling terminal emulator for Linux using GTK+ 3

%package -n nautilus-extension-tilix
Summary:        Nautilus Extension to Open Tilix in Folders
Group:          System/GUI/GNOME
Requires:       python-nautilus
Supplements:    packageand(nautilus:%{name})

%description -n nautilus-extension-tilix
This is a Nautilus extension that allows you to open tilix in
arbitrary folders.

%lang_package

%prep
%setup -q -a 1
%patch0 -p 0
%patch1 -p 1

%build
# Register local GtkD repository in dub
dub add-local GtkD-%{gtkd_version} %{gtkd_version}

# Build tilix
dub build --build=release

# De-register local GtkD repository in dub
dub remove-local GtkD-%{gtkd_version}

%install
./install.sh %{buildroot}%{_prefix}
rm %{buildroot}%{_datadir}/glib-2.0/schemas/gschemas.compiled

%find_lang %{name} %{?no_lang_C}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/%{name}/resources/
%{_datadir}/%{name}/resources/tilix.gresource
%{_datadir}/%{name}/schemes/
%{_datadir}/%{name}/scripts/
%attr(755, -, -) %{_datadir}/%{name}/scripts/tilix_int.sh
%{_mandir}/man1/tilix.1%{?ext_man}
%{_datadir}/metainfo/
%{_datadir}/metainfo/com.gexperts.Tilix.appdata.xml
%{_datadir}/icons/hicolor/16x16/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/22x22/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/24x24/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/256x256/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/32x32/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/48x48/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/512x512/apps/com.gexperts.Tilix.png
%{_datadir}/icons/hicolor/scalable/apps/com.gexperts.Tilix-symbolic.svg
%{_datadir}/applications/com.gexperts.Tilix.desktop
%{_datadir}/dbus-1/services/com.gexperts.Tilix.service
%{_datadir}/glib-2.0/schemas/com.gexperts.Tilix.gschema.xml

%files -n nautilus-extension-tilix
%{_datadir}/nautilus-python/
%{_datadir}/nautilus-python/extensions/
%{_datadir}/nautilus-python/extensions/open-tilix.py

%files lang -f %{name}.lang

%changelog
* Sat Apr 14 2018 matthias.eliasson@gmail.com
- Add patch: dynamic-link.patch: link against shared library
- Use %%license macro
* Wed Mar 14 2018 michele.bologna@suse.com
- Update to 1.7.7
- Added patch: gnome-ssh-agent.patch
  * Solves the problem with GNOME keyring and ssh-agent:
  https://github.com/gnunn1/tilix/issues/870#issuecomment-291849303
* Sat Jan 13 2018 matthias.eliasson@gmail.com
- Update to 1.7.5
  * Fixed segfault with input synchronization occurring after a period of time (gh#gnunn1/tilix#1228)
  * Passwords and bookmarks now respect input synchronization (gh#gnunn1/tilix#1236)
  * Fix problem with Copy as HTML not checking VTE version (gh#gnunn1/tilix#1235)
- Update copyright year
- Remove patch: tilix-fix-1.7.3-build-on-32bits.patch (fixed upstream)
* Mon Jan  1 2018 matthias.eliasson@gmail.com
- Update to 1.7.3
  * This release improves the stability of Tilix plus fixes a few minor issues.
    The only new feature is being able to copy terminal output as HTML.
- Update version of build dependency gtkd to 3.7.3
- Remove patch: tilix-fix-1.7.1-build-on-32bits.patch (fixed upstream)
- Add patch: tilix-fix-1.7.3-build-on-32bits.patch
- Should now build on i586 arch
* Thu Dec 21 2017 mimi.vx@gmail.com
- remove unnneded post/postun sections
* Fri Dec  1 2017 matthias.eliasson@gmail.com
- Fix so tilix runs correctly
* Wed Nov 22 2017 matthias.eliasson@gmail.com
- Add tilix-fix-1.7.1-build-on-32bits.patch to fix builds on i586
* Wed Nov 22 2017 matthias.eliasson@gmail.com
- Update to version 1.7.1
  * This release fixes a single issue with 1.7.0 where the default for the overlay scrollbar was set to false.
- Run spec-cleaner
- Remove buildignore for gcc-PIE not needed anymore.
- Bump version of build dependency gtkd to 3.6.6
* Sun Jul 23 2017 matthias.eliasson@gmail.com
- Remove _service and add the specific source files
* Sat Jul 22 2017 matthias.eliasson@gmail.com
- bump version to 1.6.4
  * Dim option now dims the fonts and does not alter the background. The dim color option has been removed
  * Added option to disable saving/restoring window state between invocations
  * Added option to disable overlay scrollbar in favor of separate scrollbar widget
  * Fixed problem with selecting non-existent bookmark causing a crash
  * Enabled customizing keyboard shortcut for toggling local input synchronization
  * Added abilitiy to specify window style from command line
  * Added menu option to open CWD in file browser (i.e. Nautilus, etc)
  * Fixed issue where opening a custom link could only be done once
- bump version of build dependency gtkd to 3.6.5
- spec-cleaner
- add buildignore gcc-PIE to make this build for now are waiting for some fixes upstream:
  https://github.com/dlang/phobos/pull/5586
* Fri Apr 28 2017 matthias.eliasson@gmail.com
- bump version to 1.5.6
  * Added the ability to specify custom hyperlinks and triggers globally as well as in profiles
  * Triggers now support executing a process and passing the output of the process to the terminal
  * Fixed issue for CentOS and RHEL 7.x where it would not run on GTK 3.14
  * Sidebar now ensures active session is shown when opening
  * Removed the option to disable animation in quake mode, was causing other issues
  * Fixed New Window options Split Down and Split Right
  * Fixed various focus issues
  * Added option to bookmarks to automatically insert line feed
  * Fixed Wayland issue where dragging and dropping a terminal on the desktop did not create a new window like it does in X11
* Mon Mar 27 2017 vinadoros@outlook.com
- Upstream rename from terminix to tilix
- bump version to 1.5.4
  * Detaching terminal in Wayland by dropping it on desktop now works identically to X11
  * Fixed issue with outdated LDC libraries on Fedora, this should allow COPR to work again
  * Fixed issue with close dialog and long process names resulting in excessively wide dialog box
  * Removed animation hint feature from quake mode as it was causing focus issues
  * Fixed crash when loading multiple sessions from file
* Wed Mar  8 2017 matthias.eliasson@gmail.com
- bump version to 1.5.2
  * Removed Timeout from terminal to fix segfault with visual bell
  * Fixed Nautilus plugin where it was crashing Nautilus for some users thanks to @bil-elmoussaoui
  * Variables used in application title now resolve correctly.
  * Fix version number
* Tue Feb 21 2017 kkaempf@suse.com
- bump version to 1.5.0
  * Added initial support for bookmarks
  * Re-worked terminal menu to include bookmark and password options,
    some lesser used options moved to a sub-menu
  * Added a new feature to raise a notification if activity is
    detected after a specified period of silence
  * Search button now toggles depending if focused terminal has
    search open
  * Improved performance when using background images
  * Added new Window Appearance preference
  * Improved title editors in preferences to show available variables
  * Re-worked -e option to fix some bugs, should work better across
    more permutations
  * Many bug fixes
- update GtkD to 3.5.1
* Mon Jan 16 2017 matthias.eliasson@gmail.com
- bump version to 1.4.2
- add man page to files section
* Mon Dec 26 2016 matthias.eliasson@gmail.com
- bump version 1.4.0
- remove desktop.patch since this have been fixed upstream.
- Modified %%files section to include all files for package
* Fri May  6 2016 mailaender@opensuse.org
- initial packaging of version 0.59.0
